@@ -17,8 +17,8 @@ module Doorkeeper
           super.tap do |owner|
             next unless oidc_authorization_request?
 
-            handle_oidc_prompt_param!(owner)
             handle_oidc_max_age_param!(owner)
+            handle_oidc_prompt_param!(owner)
           end
         rescue Errors::OpenidConnectError => e
           handle_oidc_error!(e)
@@ -67,6 +67,11 @@ module Doorkeeper
         def handle_oidc_prompt_param!(owner)
           prompt_values ||= params[:prompt].to_s.split(/ +/).uniq
 
+          priority = ['none', 'consent', 'login', 'select_account']
+          prompt_values.sort_by! do |prompt|
+            priority.find_index(prompt).to_i
+          end
+
           prompt_values.each do |prompt|
             case prompt
             when 'none'
@@ -79,6 +84,8 @@ module Doorkeeper
               render :new if owner
             when 'select_account'
               select_account_for_oidc_resource_owner(owner)
+            when 'create'
+              # NOTE: not supported, but not raise error.
             else
               raise Errors::InvalidRequest
             end
@@ -87,13 +94,16 @@ module Doorkeeper
 
         def handle_oidc_max_age_param!(owner)
           max_age = params[:max_age].to_i
-          return unless max_age > 0 && owner
+          return unless (params[:max_age].to_s == '0' || max_age > 0) && owner
 
           auth_time = instance_exec(
             owner,
             &Doorkeeper::OpenidConnect.configuration.auth_time_from_resource_owner
           )
 
+          # NOTE: clock skew
+          max_age = [1, max_age].max
+
           if !auth_time || (Time.zone.now - auth_time) > max_age
             reauthenticate_oidc_resource_owner(owner)
           end
