@@ -7,11 +7,12 @@ module Doorkeeper
 
       attr_reader :nonce
 
-      def initialize(access_token, nonce = nil)
+      def initialize(access_token, nonce = nil, expires_in = Doorkeeper::OpenidConnect.configuration.expiration)
         @access_token = access_token
         @nonce = nonce
         @resource_owner = Doorkeeper::OpenidConnect.configuration.resource_owner_from_access_token.call(access_token)
         @issued_at = Time.zone.now
+        @expires_in = expires_in
       end
 
       def claims
@@ -34,7 +35,7 @@ module Doorkeeper
         ::JWT.encode(as_json,
           Doorkeeper::OpenidConnect.signing_key.keypair,
           Doorkeeper::OpenidConnect.signing_algorithm.to_s,
-          { kid: Doorkeeper::OpenidConnect.signing_key.kid }
+          { typ: 'JWT', kid: Doorkeeper::OpenidConnect.signing_key.kid }
         ).to_s
       end
 
@@ -57,7 +58,7 @@ module Doorkeeper
       end
 
       def expiration
-        (@issued_at.utc + Doorkeeper::OpenidConnect.configuration.expiration).to_i
+        (@issued_at.utc + @expires_in).to_i
       end
 
       def issued_at
