@@ -82,14 +82,14 @@ describe Doorkeeper::AuthorizationsController, type: :controller do
         it 'render error when client_id is missing' do
           authorize!(client_id: nil)
 
-          expect(response).to be_successful
+          expect(response).to have_http_status(:bad_request)
           expect(response).to render_template('doorkeeper/authorizations/error')
         end
 
         it 'render error when response_type is missing' do
           authorize!(response_type: nil)
 
-          expect(response).to be_successful
+          expect(response).to have_http_status(:bad_request)
           expect(response).to render_template('doorkeeper/authorizations/error')
         end
       end
@@ -284,6 +284,41 @@ describe Doorkeeper::AuthorizationsController, type: :controller do
       end
     end
 
+    context 'with a prompt=create parameter' do
+      it 'ignore it w/o returinig invalid_request error' do
+        authorize! prompt: 'create'
+
+        expect(response).to render_template('doorkeeper/authorizations/new')
+      end
+    end
+
+    context 'with multiple prompt values' do
+      it 'when select_account+login' do
+        authorize! prompt: 'select_account login'
+        expect(response).to redirect_to('/select_account')
+      end
+
+      it 'when login+select_account' do
+        authorize! prompt: 'login select_account'
+        expect(response).to redirect_to('/select_account')
+      end
+
+      it 'when consent+select_account' do
+        authorize! prompt: 'consent select_account'
+        expect(response).to redirect_to('/select_account')
+      end
+
+      it 'when select_account+consent' do
+        authorize! prompt: 'select_account consent'
+        expect(response).to redirect_to('/select_account')
+      end
+
+      it 'when login+consent' do
+        authorize! prompt: 'login consent'
+        expect(response).to redirect_to('/reauthenticate')
+      end
+    end
+
     context 'with an unknown prompt parameter' do
       it 'returns an invalid_request error' do
         authorize! prompt: 'maybe'
@@ -307,7 +342,7 @@ describe Doorkeeper::AuthorizationsController, type: :controller do
   describe '#handle_oidc_max_age_param!' do
     context 'with an invalid max_age parameter' do
       it 'renders the authorization form' do
-        %w[0 -1 -23 foobar].each do |max_age|
+        %w[-1 -23 foobar].each do |max_age|
           authorize! max_age: max_age
 
           expect_authorization_form!
@@ -315,6 +350,15 @@ describe Doorkeeper::AuthorizationsController, type: :controller do
       end
     end
 
+    context 'with a max_age=0 parameter' do
+      it 'renders the authorization form if the users last login was within 10 seconds' do
+        user.update! current_sign_in_at: 5.seconds.ago
+        authorize! max_age: 0
+
+        expect(response).to redirect_to '/reauthenticate'
+      end
+    end
+
     context 'with a max_age=10 parameter' do
       it 'renders the authorization form if the users last login was within 10 seconds' do
         user.update! current_sign_in_at: 5.seconds.ago
@@ -337,6 +381,15 @@ describe Doorkeeper::AuthorizationsController, type: :controller do
         expect(response).to redirect_to '/reauthenticate'
       end
     end
+
+    context 'when used along with prompt=select_account' do
+      it 'renders the authorization form' do
+        user.update! current_sign_in_at: 5.seconds.ago
+        authorize! max_age: 1, prompt: 'select_account'
+
+        expect(response).to redirect_to '/select_account'
+      end
+    end
   end
 
   describe '#reauthenticate_oidc_resource_owner' do
