@@ -11,10 +11,15 @@ describe Doorkeeper::OpenidConnect::AccessGrant do
     expect(association.options).to eq({
       class_name: 'Doorkeeper::OpenidConnect::Request',
       inverse_of: :access_grant,
+      foreign_key: "access_grant_id",
       dependent: :delete,
     })
   end
 
+  it 'extends the base doorkeeper AccessGrant' do
+    expect(subject).to respond_to(:"openid_request=")
+  end
+
   describe '#delete' do
     it 'cascades to oauth_openid_requests' do
       if Rails::VERSION::MAJOR >= 6
